import React from 'react';

type HistoryItem = {
  tier: string;
  winnings: number;
  winningNumbers: number[];
  fields: number[];
};

type HistoryListProps = {
  history: HistoryItem[];
};

const HistoryList: React.FC<HistoryListProps> = React.memo(({ history }) => {
  if (history.length === 0) return null;
  return (
    <div className="w-full max-w-md mb-8">
      <div className="font-semibold text-gray-700 mb-2">Play History</div>
      <ul className="divide-y divide-gray-200 bg-white rounded-lg shadow">
        {history.map((h, i) => (
          <li key={i} className="p-3 flex flex-col sm:flex-row sm:items-center sm:justify-between">
            <div>
              <span className="font-bold text-blue-600">{h.tier}</span>
              <span className="ml-2 text-gray-500">Win: ${h.winnings}</span>
            </div>
            <div className="flex gap-2 mt-2 sm:mt-0">
              {h.winningNumbers.map((n, j) => (
                <span key={j} className="w-6 h-6 flex items-center justify-center rounded-full bg-blue-100 text-blue-700 text-xs font-bold border border-blue-300">{n}</span>
              ))}
            </div>
            <div className="flex gap-1 mt-2 sm:mt-0">
              {h.fields.map((n, j) => (
                <span
                  key={j}
                  className={`w-5 h-5 flex items-center justify-center rounded text-xs border ${
                    h.winningNumbers.includes(n)
                      ? 'bg-green-100 text-green-700 border-green-300'
                      : 'bg-gray-100 text-gray-700 border-gray-300'
                  }`}
                >
                  {n}
                </span>
              ))}
            </div>
          </li>
        ))}
      </ul>
    </div>
  );
});

export default HistoryList; 