import React from 'react';
import type { Tier } from '../App';

type TierCardProps = {
  tier: Tier;
  unlocked: boolean;
  money: number;
  gubblePointChance: number;
  onUnlock: (tier: Tier) => void;
  onBuy: (tier: Tier) => void;
};

const TierCard: React.FC<TierCardProps> = React.memo(({ tier, unlocked, money, onUnlock, onBuy }) => {
    const formatter = Intl.NumberFormat(
      'en', 
      { 'notation': 'compact' }
      )
  return (
    <button
      className={`rounded-lg shadow p-2 flex flex-col items-center w-32 font-bold text-white mb-1 disabled:opacity-50 ${
        !unlocked
          ? 'bg-yellow-400 hover:bg-yellow-500'
          : 'bg-green-500 hover:bg-green-600'
      }`}
      disabled={!unlocked ? money < tier.unlockPrice : money < tier.buyPrice}
      onClick={() => (!unlocked ? onUnlock(tier) : onBuy(tier))}
    >
      <div className="text-lg font-semibold mb-1">{tier.name}</div>
      <div className="text-gray-500 text-xs mb-1">
        Unlock: ${formatter.format(tier.unlockPrice)}
      </div>
      <div className="text-gray-500 text-xs mb-1">
        Buy:  ${formatter.format(tier.buyPrice)}
      </div>
      <div className="text-gray-500 text-xs mb-1">Point Chance: {tier.gubblePointChance * 100}%</div>
      <div>
        {!unlocked ? 'Unlock' : 'Buy Card'}
      </div>
    </button>
  );
});

export default TierCard; 